@@ -33,12 +33,13 @@ class MedicalVisit(SQLModel, table=True):
 
     next_followup_visit_id:Optional[uuid.UUID]=Field(default=None,foreign_key="medical_visit.medical_visit_id")
 
-    overall_diagnosis:str
+    overall_diagnosis:Optional[str]=Field(default=None)
 
     bridge_area_floor_branch_id:Optional[uuid.UUID]=Field(default=None,foreign_key="bridge_area_floor_branch.bridge_area_floor_branch_id")
     bridge_area_floor_branch: Optional[BridgeAreaFloorBranch] = Relationship()
 
     reason_visit:Optional[str]=Field(default=None)
+    current_illness: Optional[str]=Field(default=None)
     rest: Optional[bool] = Field(default=None)
     rest_hours: Optional[int] = Field(default=None)
     rest_date_start: Optional[datetime] = Field(default=None)
