@@ -1,6 +1,6 @@
 from typing import Optional, List
 from uuid import UUID
-from sqlmodel import select
+from sqlmodel import select, or_
 
 from healthdatalayer.models import MedicalDiagnosis
 from healthdatalayer.config.db import engines, get_session
@@ -32,9 +32,14 @@ class MedicalDiagnosisRepository:
             medical_diagnosis = session.exec(statement).first()
             return medical_diagnosis
     
-    def get_by_name_ilike_command(self, name:str, active_only: bool = True) -> List[MedicalDiagnosis]:
+    def get_by_name_code_ilike_command(self, name:str, active_only: bool = True) -> List[MedicalDiagnosis]:
         with get_session(self.tenant) as session:
-            statement = select(MedicalDiagnosis).where(MedicalDiagnosis.name.ilike(f"%{name}%"))
+            statement = select(MedicalDiagnosis).where(
+                or_(
+                MedicalDiagnosis.name.ilike(f"%{name}%"), 
+                MedicalDiagnosis.cie_10_code.ilike(f"%{name}%")
+                )
+            )
             
             if active_only:
                 statement = statement.where(MedicalDiagnosis.is_active == True)
