@@ -1,9 +1,10 @@
 from typing import Optional, List
 from datetime import datetime, date, time
 from uuid import UUID
-from sqlmodel import select
+from sqlmodel import select, text
 from sqlalchemy.orm import selectinload,joinedload
 from healthdatalayer.models import MedicalVisit
+from healthdatalayer.dtos import MedicalCertificateDTO
 from healthdatalayer.config.db import engines, get_session
 
 class MedicalVisitRepository:
@@ -342,4 +343,139 @@ class MedicalVisitRepository:
             statement = select(MedicalVisit).where(MedicalVisit.collaborator_id == collaborator_id, MedicalVisit.visit_date == target_date)
             result = session.exec(statement).first()
             return result is not None
-    
\ No newline at end of file
+    
+    
+    def get_data_medical_certificate_command(self, medical_visit_id: str) -> MedicalCertificateDTO:
+    
+        with get_session(self.tenant) as session:
+            
+            query = text("""
+                select 
+                s."name"  as "sys",
+                b2."name" as stablishment,
+                px.medical_record_number,
+                px.identification  as number_his,
+                px.last_name ,
+                px.first_name,
+                case 
+                    when g.name ='Male' then 'M'
+                    else 'F'
+                end as sex,
+                EXTRACT(YEAR FROM AGE(px.birth_date)) AS age,
+                sp.name as service,
+                sp.subspeciality as speciality,
+                EXTRACT(YEAR FROM mv.visit_date) AS year_visit,
+                EXTRACT(MONTH FROM mv.visit_date) AS month_visit,
+                EXTRACT(DAY FROM mv.visit_date) AS day_visit,
+                mv.visit_date::time AS hour_start,
+                (mv.visit_date + INTERVAL '30 minutes')::time AS hour_end,
+                TO_CHAR(mv.visit_date, 'DD') || ' de ' ||
+                CASE EXTRACT(MONTH FROM mv.visit_date)
+                    WHEN 1 THEN 'enero'
+                    WHEN 2 THEN 'febrero'
+                    WHEN 3 THEN 'marzo'
+                    WHEN 4 THEN 'abril'
+                    WHEN 5 THEN 'mayo'
+                    WHEN 6 THEN 'junio'
+                    WHEN 7 THEN 'julio'
+                    WHEN 8 THEN 'agosto'
+                    WHEN 9 THEN 'septiembre'
+                    WHEN 10 THEN 'octubre'
+                    WHEN 11 THEN 'noviembre'
+                    WHEN 12 THEN 'diciembre'
+                END || ' del ' || EXTRACT(YEAR FROM mv.visit_date) AS visit_date_spanish,
+                mv.rest,
+                mv.rest_hours, 
+                mv.rest_date_start , 
+                EXTRACT(YEAR FROM mv.rest_date_start) AS year_rest_start,
+                EXTRACT(MONTH FROM mv.rest_date_start) AS month_rest_start,
+                EXTRACT(DAY FROM mv.rest_date_start) AS day_rest_start,
+                TO_CHAR(mv.rest_date_start, 'DD') || ' de ' ||
+                CASE EXTRACT(MONTH FROM mv.rest_date_start)
+                    WHEN 1 THEN 'enero'
+                    WHEN 2 THEN 'febrero'
+                    WHEN 3 THEN 'marzo'
+                    WHEN 4 THEN 'abril'
+                    WHEN 5 THEN 'mayo'
+                    WHEN 6 THEN 'junio'
+                    WHEN 7 THEN 'julio'
+                    WHEN 8 THEN 'agosto'
+                    WHEN 9 THEN 'septiembre'
+                    WHEN 10 THEN 'octubre'
+                    WHEN 11 THEN 'noviembre'
+                    WHEN 12 THEN 'diciembre'
+                END || ' del ' || EXTRACT(YEAR FROM mv.rest_date_start) AS rest_date_start_spanish,
+                mv.rest_date_end,
+                EXTRACT(YEAR FROM mv.rest_date_end) AS year_rest_end,
+                EXTRACT(MONTH FROM mv.rest_date_end) AS month_rest_end,
+                EXTRACT(DAY FROM mv.rest_date_end) AS day_rest_end,
+                TO_CHAR( mv.rest_date_end, 'DD') || ' de ' ||
+                CASE EXTRACT(MONTH FROM  mv.rest_date_end)
+                    WHEN 1 THEN 'enero'
+                    WHEN 2 THEN 'febrero'
+                    WHEN 3 THEN 'marzo'
+                    WHEN 4 THEN 'abril'
+                    WHEN 5 THEN 'mayo'
+                    WHEN 6 THEN 'junio'
+                    WHEN 7 THEN 'julio'
+                    WHEN 8 THEN 'agosto'
+                    WHEN 9 THEN 'septiembre'
+                    WHEN 10 THEN 'octubre'
+                    WHEN 11 THEN 'noviembre'
+                    WHEN 12 THEN 'diciembre'
+                END || ' del ' || EXTRACT(YEAR FROM  mv.rest_date_end) AS rest_date_end_spanish,
+                c.name as doctor_name,
+                c.ruc  as doctor_ruc
+                from medical_visit mv
+                left join px on px.client_id  = mv.client_id 
+                left join gender g on g.gender_id  = px.gender_id 
+                left join collaborator c on c.collaborator_id  = mv.collaborator_id 
+                left join bridge_area_floor_branch b on b.bridge_area_floor_branch_id  = mv.bridge_area_floor_branch_id 
+                left join branch b2 on b.branch_id  = b2.branch_id 
+                left join "system" s on s.system_id  = b2.system_id 
+                left join speciality sp on sp.speciality_id = mv.speciality_id
+                where mv.medical_visit_id = :medical_visit_id
+                and mv.status_visit != 'CANCELADO'
+            """)
+            
+            result = session.exec(query, params={"medical_visit_id": medical_visit_id})
+            
+            row = result.fetchone()
+        
+            
+            if not row:
+                raise ValueError(f"No se encontró la visita médica con ID: {medical_visit_id}")
+            
+            
+            return MedicalCertificateDTO(
+                sys=row[0],
+                stablishment=row[1],
+                medical_record_number=row[2],
+                number_his=row[3],
+                last_name=row[4],
+                first_name=row[5],
+                sex=row[6],
+                age=row[7],
+                service=row[8],
+                speciality=row[9],
+                year_visit=row[10],
+                month_visit=row[11],
+                day_visit=row[12],
+                hour_start=row[13],
+                hour_end=row[14],
+                visit_date_spanish=row[15],
+                rest=row[16],
+                rest_hours=row[17],
+                rest_date_start=row[18],
+                year_rest_start=row[19],
+                month_rest_start=row[20],
+                day_rest_start=row[21],
+                rest_date_start_spanish=row[22],
+                rest_date_end=row[23],
+                year_rest_end=row[24],
+                month_rest_end=row[25],
+                day_rest_end=row[26],
+                rest_date_end_spanish=row[27],
+                doctor_name=row[28],
+                doctor_ruc=row[29]
+            )
\ No newline at end of file
